import pycodestyle
from py_gardener.InternalTestBase import InternalTestBase


class TestPep8(InternalTestBase):
    """ Test that we conform to PEP8. """

    def test_pep8(self):
        line_length = self.OPTIONS.get('max-line-length', 80)
        pep8style = pycodestyle.StyleGuide(
            quiet=False,
            paths=['--max-line-length=%s' % line_length]
        )
        result = pep8style.check_files(self.list_project_files())
        assert result.total_errors == 0, "Found pep8 problems"



import os
import pathlib
from shutil import copyfile
from py_gardener.InternalTestBase import InternalTestBase


class TestDocker(InternalTestBase):

    def test_docker(self):
        """ Test that tests are run inside a Docker container """
        if len(self.DOCKER) > 0:
            assert os.path.exists(os.path.join("/.dockerenv")), (
                'Please run in Docker using ". manage.sh"')

    def test_copy_docker_files(self):
        """ Test to copy lambda files into directory """
        if self.ROOT_DIR is None:
            return
        for type_ in self.DOCKER:
            base = os.path.join(
                os.path.dirname(__file__),
                "resources",
                "docker",
                type_
            )
            copyfile(
                os.path.join(base, 'manage.sh'),
                os.path.join(self.ROOT_DIR, 'manage.sh')
            )
            pathlib.Path(os.path.join(self.ROOT_DIR, 'docker')).mkdir(
                parents=True,
                exist_ok=True
            )
            copyfile(
                os.path.join(base, 'Dockerfile'),
                os.path.join(self.ROOT_DIR, 'docker', 'Dockerfile')
            )



from py_gardener.TestIncorrectBoolConditional import (
    TestIncorrectBoolConditional)
from py_gardener.TestLineEndings import TestLineEndings
from py_gardener.TestPep8 import TestPep8
from py_gardener.TestPylint import TestPylint
from py_gardener.TestStructure import TestStructure
from py_gardener.TestVersionConsistent import TestVersionConsistent
from py_gardener.TestDocker import TestDocker


class StaticTestBase(
    TestIncorrectBoolConditional,
    TestLineEndings,
    TestPep8,
    TestPylint,
    TestStructure,
    TestVersionConsistent,
    TestDocker
):
    pass
